VERBS = [
    'aç',
    'ağla',
    'ak',
    'al',
    'anla',
    'anlat',
    'ara',
    'art',
    'aş',
    'at',
    'ayır',
    'ayrıl',
    'azal',
    'bağır',
    'bağla',
    'bak',
    'bas',
    'başla',
    'bekle',
    'belirle',
    'belirt',
    'benze',
    'bırak',
    'bil',
    'bin',
    'bitir',
    'bit',
    'bozul',
    'bul',
    'büyü',
    'çalış',
    'çal',
    'çekil',
    'çek',
    'çevir',
    'çıkar',
    'çık',
    'çiz',
    'dayan',
    'değerlendir',
    'değiş',
    'değiştir',
    'de',
    'devam et',
    'dikkat et',
    'dile',
    'dinle',
    'doğ',
    'dolaş',
    'doldur',
    'dön',
    'dönüş',
    'dur',
    'duy',
    'düş',
    'düşün',
    'düzenle',
    'ekle',
    'etkile',
    'et',
    'evlen',
    'fark et',
    'geçir',
    'geç',
    'geliş',
    'geliştir',
    'gel',
    'gerçekleş',
    'gerek',
    'getir',
    'gir',
    'git',
    'giy',
    'gönder',
    'gör',
    'görün',
    'görüş',
    'göster',
    'götür',
    'gül',
    'hareket et',
    'hatırla',
    'hazırla',
    'hisset',
    'iç',
    'ifade et',
    'ilerle',
    'ilgilen',
    'inan',
    'incele',
    'in',
    'iste',
    'izle',
    'kabul et',
    'kaç',
    'kaldır',
    'kalk',
    'kal',
    'kapat',
    'karış',
    'karıştır',
    'karşıla',
    'karşılaş',
    'katıl',
    'kaybet',
    'kazan',
    'kes',
    'kıl',
    'konuş',
    'kork',
    'kor',
    'koş',
    'koy',
    'kullan',
    'kur',
    'kurtar',
    'kurtul',
    'ok',
    'ol',
    'oluş',
    'otur',
    'oyna',
    'öde',
    'öğren',
    'öldür',
    'öl',
    'paylaş',
    'sağla',
    'sahip ol',
    'san',
    'satın al',
    'sat',
    'say',
    'seç',
    'sev',
    'seyret',
    'sok',
    'sor',
    'söyle',
    'söylen',
    'söz et',
    'sun',
    'sürdür',
    'sür',
    'tanı',
    'taşı',
    'tercih et',
    'topla',
    'toplan',
    'tut',
    'uğraş',
    'ulaş',
    'unut',
    'uygula',
    'uy',
    'uzan',
    'uzat',
    'üret',
    'var',
    'ver',
    'vur',
    'yakala',
    'yaklaş',
    'yak',
    'yan',
    'yap',
    'yararlan',
    'yarat',
    'yardımcı ol',
    'yaşa',
    'yat',
    'yay',
    'yayımlan',
    'yaz',
    'ye',
    'yüksel',
    'yürü',
]
